All

Trait All 

pub trait All { }
The All trait provides a workaround to the current parsing problem of a lack of truly unbounded type operator arguments. It’s implemented for all types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: ?Sized> All for T